@@ -83,7 +83,6 @@ class AreaService(BaseRdbmsService):
 
     def find_areas_with_ip_address(
             self,
-            app_id,
             ip_address,
             connection=None,
             lowest_area_level=5,
@@ -93,9 +92,6 @@ class AreaService(BaseRdbmsService):
         Return information of a list of areas that encompass the IP address.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param ip_address: a dotted-decimal notation of an IPv4 address,
             consisting of four decimal numbers, each ranging from ``0`` to
             ``255``, separated by dots.
@@ -199,17 +195,13 @@ class AreaService(BaseRdbmsService):
             return areas
 
     def find_location_with_ip_address(
-            self, 
-            app_id, 
+            self,
             ip_address,
             connection=None):
         """
         Return the location based on the specified IP address.
 
 
-        :param app_id: Identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param ip_address: A dotted-decimal notation of an IPv4 address,
             consisting of four decimal numbers, each ranging from ``0`` to
             ``255``, separated by dots.
@@ -249,7 +241,6 @@ class AreaService(BaseRdbmsService):
 
     def get_area_boundaries(
             self,
-            app_id,
             area_id,
             connection=None,
             sync_time=None):
@@ -257,9 +248,6 @@ class AreaService(BaseRdbmsService):
         Return the boundaries of the specified geographic area.
 
 
-        :param app_id: Identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param area_id: Identification of the geographic area to return its
             boundaries.
 
@@ -360,7 +348,11 @@ class AreaService(BaseRdbmsService):
             row = cursor.fetch_one()
             return row and row.get_value('area_extended_id')
 
-    def get_areas(self, app_id, area_ids, connection=None, locale=DEFAULT_LOCALE):
+    def get_areas(
+            self,
+            area_ids,
+            connection=None,
+            locale=DEFAULT_LOCALE):
         """
         Return the specified geographic areas worth of extended information.
 
@@ -368,9 +360,6 @@ class AreaService(BaseRdbmsService):
         returned in the results list.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param area_ids: a list of identifications of geographic areas.
 
         :param connection: A `RdbmsConnection` instance to be used supporting
@@ -454,7 +443,6 @@ class AreaService(BaseRdbmsService):
 
     def get_areas_in_bounding_box(
             self,
-            app_id,
             bounding_box,
             connection=None,
             locale=DEFAULT_LOCALE):
@@ -462,9 +450,6 @@ class AreaService(BaseRdbmsService):
         Return the geographic areas that intersect the specified bounding box.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param bounding_box: a tuple of two instances ``GeoPoint`` that
             represent the north-east corner and the south-west corners of the
             rectangle area to search places in.
@@ -548,7 +533,6 @@ class AreaService(BaseRdbmsService):
 
     def get_areas_by_ip_address(
             self,
-            app_id,
             ip_address,
             connection=None,
             lowest_area_level=area.AREA_LEVEL_WARD,
@@ -560,9 +544,6 @@ class AreaService(BaseRdbmsService):
         from the specified IP address.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param ip_address: a dotted-decimal notation of an IPv4 address,
             consisting of four decimal numbers, each ranging from ``0`` to
             ``255``, separated by dots.
@@ -633,7 +614,6 @@ class AreaService(BaseRdbmsService):
 
     def get_areas_by_keywords(
             self,
-            app_id,
             keywords,
             connection=None,
             highest_area_level=None,
@@ -646,9 +626,6 @@ class AreaService(BaseRdbmsService):
         Return the geographic areas that match the specified keywords.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param keywords: a list of one or more keywords.
 
         :param connection: A `RdbmsConnection` instance to be used supporting
@@ -666,20 +643,22 @@ class AreaService(BaseRdbmsService):
             Note: the smallest the area, the fastest the function returns
             result.
 
-        :param highest_area_level: the level of the largest administrative
+        :param highest_area_level: The level of the largest administrative
             area to finish with.
 
-        :param limit: constrain the number of areas that are returned to the
+        :param limit: Constrain the number of areas that are returned to the
             specified number.
 
+        :param locale: An object ``Locale`` that specifies the locale of the
+             area labels to be returned.
+
+        :param minimal_area_surface: Minimal surface of the areas to return.
+
         :param offset: require to skip that many areas before beginning to
             return them.  If both ``limit`` and ``offset`` are specified, then
             ``offset`` areas are skipped before starting to count the
             `limit`` areas that are returned.  The default value is ``0``.
 
-        :param locale: a ``Locale`` instance that specifies the locale of the
-             area labels to be returned.
-
 
         :return: an instance containing the following members:
 
@@ -769,7 +748,6 @@ class AreaService(BaseRdbmsService):
 
     def get_areas_by_location(
             self,
-            app_id,
             location,
             connection=None,
             lowest_area_level=area.AREA_LEVEL_WARD,
@@ -780,9 +758,6 @@ class AreaService(BaseRdbmsService):
         Return the geographic areas that encompass the specified location.
 
 
-        :param app_id: identification of the client application such as a Web,
-            a desktop, or a mobile application, that accesses the service.
-
         :param location: a ``GeoPoint`` instance that specifies a location.
 
         :param connection: A `RdbmsConnection` instance to be used supporting
